;; Generated package description from shift-number.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "shift-number" "0.3.0.20260620.18" "Increase/decrease the number at point" '((emacs "28.1")) :commit "d5e8bece6e6ab21ad5a93330d49b2554e9eb72a9" :authors '(("Alex Kost" . "alezost@gmail.com")) :maintainer '("Campbell Barton" . "ideasman42@gmail.com") :keywords '("convenience") :url "https://codeberg.org/ideasman42/emacs-shift-number")
